==> haskell-monad-logger-0.3.35-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-logger
version:              0.3.35
visibility:           public
id:                   monad-logger-0.3.35-LZpaArVlmxKAzkMIiJpPmB
key:                  monad-logger-0.3.35-LZpaArVlmxKAzkMIiJpPmB
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  9ef0b43e4fe259481816a0f0b2298880
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-8.10.2/site-local/monad-logger-0.3.35
library-dirs:         /usr/lib/ghc-8.10.2/site-local/monad-logger-0.3.35
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/monad-logger-0.3.35
hs-libraries:         HSmonad-logger-0.3.35-LZpaArVlmxKAzkMIiJpPmB
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    conduit-1.3.2-LNtVbRYF6JQ4tYeIfgK6go
    conduit-extra-1.3.5-ERC0GC3cbdaH1UzTKwmTLk exceptions-0.10.4
    fast-logger-3.0.1-HzdHtdzMJfFCaAARu1r0lG
    lifted-base-0.2.3.12-7qXjOOhOKseKGf8zmVNHgP
    monad-control-1.0.2.3-8y9R5MrVeGDlsyvCtuovd
    monad-loops-0.4.3-C0LVokhtCoUF1FVS5cJB0Q mtl-2.2.2
    resourcet-1.2.4.2-5NhDKKA69zVH3p2tdnHjtN stm-2.5.0.0
    stm-chans-3.0.0.4-IkLPF4Ira3LYY9IzoULtB template-haskell-2.16.0.0
    text-1.2.3.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-CjQNf7cAS4OKmJApB9SWyv
    transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-logger-0.3.35-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-logger
version:              0.3.35
visibility:           public
id:                   monad-logger-0.3.35-1z0gzaFBX6672YKqobitGV
key:                  monad-logger-0.3.35-1z0gzaFBX6672YKqobitGV
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  3932b5d3d896e2923b346dbe24786c85
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-8.10.2/site-local/monad-logger-0.3.35
library-dirs:         /usr/lib/ghc-8.10.2/site-local/monad-logger-0.3.35
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/monad-logger-0.3.35
hs-libraries:         HSmonad-logger-0.3.35-1z0gzaFBX6672YKqobitGV
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    conduit-1.3.2-LNtVbRYF6JQ4tYeIfgK6go
    conduit-extra-1.3.5-BXIHs4ySUn0Ae028b1fbc4 exceptions-0.10.4
    fast-logger-3.0.1-HzdHtdzMJfFCaAARu1r0lG
    lifted-base-0.2.3.12-7qXjOOhOKseKGf8zmVNHgP
    monad-control-1.0.2.3-8y9R5MrVeGDlsyvCtuovd
    monad-loops-0.4.3-C0LVokhtCoUF1FVS5cJB0Q mtl-2.2.2
    resourcet-1.2.4.2-5NhDKKA69zVH3p2tdnHjtN stm-2.5.0.0
    stm-chans-3.0.0.4-IkLPF4Ira3LYY9IzoULtB template-haskell-2.16.0.0
    text-1.2.3.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-CjQNf7cAS4OKmJApB9SWyv
    transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
